Convert a line thickness from pixels to degrees of visual angle
Source:R/palette_prob_bg.R
px_to_visual_angle.RdInverse of visual_angle_to_px(). See its documentation for the default
viewing conditions, the convention argument, and why the conditions
should be overridden for a real setup.
Usage
px_to_visual_angle(
px,
viewing_distance_in = 30,
dpi = 96,
convention = .C4A$angle_convention
)Arguments
- px
line thickness in pixels
- viewing_distance_in
viewing distance, in inches
- dpi
display resolution, in dots (pixels) per inch
- convention
"szafir"or"standard"– seevisual_angle_to_px(). Defaults to theangle_conventionpackage option (seec4a_options()).